.. highlight:: shell

============
Installation
============


From sources
------------

The sources for nlplib can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/carlomazzaferro/mdasnlp

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/carlomazzaferro/mdasnlp/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/carlomazzaferro/mdasnlp
.. _tarball: https://github.com/carlomazzaferro/mdasnlp/tarball/master
